#
# spec file for package python-rfc3161-client
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-rfc3161-client
Version:        1.0.3
Release:        1.0.2.1.sr20250601
Summary:        Python library implementing the Time-Stamp Protocol (TSP) described in RFC 3161
License:        Apache-2.0
URL:            https://github.com/trailofbits/rfc3161-client
Source:         https://files.pythonhosted.org/packages/source/r/rfc3161-client/rfc3161_client-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module maturin >= 1.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros

BuildRequires:  cargo >= 1.56.0
BuildRequires:  cargo-packaging
BuildRequires:  rust >= 1.56.0

%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module rfc3161-client == %{version}}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module cryptography >= 43}
BuildRequires:  %{python_module pretend}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
%endif
# /SECTION
BuildRequires:  fdupes
Requires:       python-cryptography >= 43
%python_subpackages

%description
rfc3161-client is a Python library implementing the Time-Stamp
Protocol (TSP) described in RFC 3161.

%prep
%autosetup -p1 -a1 -n rfc3161_client-%{version}

%build
%if !%{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%if %{with test}
%check
%pytest_arch -k "not test_verify_leaf_certs_no_eku"
%endif

%if !%{with test}
%files %{python_files}
%{python_sitearch}/rfc3161_client
%{python_sitearch}/rfc3161_client-%{version}.dist-info
%endif

%changelog
* Mon Jun 23 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 1.0.3
  * Exposed verify_message in the actual Verify interface, not just the
    implementation
  * Fixed a bug where verification performed insufficient signature checks on
    the timestamp response itself, rather than the response's certificate chain
    (CVE-2025-52556 / bsc#1245174)
- Update to 1.0.2
  * Added HashAlgorithm to exports of the base package module
  * Added verify_message method to Verifier class
  * Slight refactoring of the tests to ease how to test with multiple TSA
  * Changed return value of VerifierBuilder.build() from _Verifier to Verifier:
    This is technically an API change but should have minimal user impact.
  * Fixed spelling of hash_algorithm parameter in TimestampRequestBuilder class
* Wed Apr 16 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.0.1
  * The Verifier now enforces that the EKU (Extended Key Usage)
    explicitly includes the `id-kp-timeStamping` OID (#120)
  * The Verifier now searches for the leaf certificate in the
    Timestamp Response instead of using the first one provided (#121)
* Tue Jan 21 2025 Daniel Garcia <daniel.garcia@suse.com>
- Initial version (1.0.0)
